@@ -25,7 +25,6 @@
 # **************************************************************************
 
 import os
-from io import open
 from numpy import rad2deg
 from numpy.linalg import inv
 
@@ -36,45 +35,45 @@ def parseOutput(filename):
     """
     result = []
     if os.path.exists(filename):
-        f = open(filename)
-        for line in f:
-            if 'Efficiency:' in line:
-                result.append(float(line.split()[1]))
-            elif 'Mean PSF resolution:' in line:
-                result.append(float(line.split()[3]))
-            elif 'Standard deviation:' in line:
-                result.append(float(line.split()[2]))
-            elif 'Worst PSF resolution:' in line:
-                result.append(float(line.split()[3]))
-            elif 'Best PSF resolution:' in line:
-                result.append(float(line.split()[3]))
-        f.close()
-    return result
+        with open(filename) as f:
+            for line in f:
+                if "Efficiency:" in line:
+                    result.append(line.split()[1])
+                    continue
+                elif "Mean PSF resolution:" in line:
+                    result.append(line.split()[3])
+                    continue
+                elif "Standard deviation:" in line:
+                    result.append(line.split()[2])
+                    continue
+                elif "Worst PSF resolution:" in line:
+                    result.append(line.split()[3])
+                    continue
+                elif "Best PSF resolution" in line:
+                    result.append(line.split()[3])
+                    break
+
+    return map(float, result)
 
 
 def iterAngles(fn):
-    f = open(fn)
-    for line in f:
-        rot, tilt = map(float, line.split())
-        yield rot, tilt
-    f.close()
+    with open(fn) as f:
+        for line in f:
+            rot, tilt = map(float, line.split())
+            yield rot, tilt
 
 
 def writeAnglesFn(img, fn):
     # get alignment parameters for each particle
-    shifts, angles = geometryFromMatrix(img.getTransform().getMatrix())
+    angles = geometryFromMatrix(img.getTransform().getMatrix())
     rot, tilt, _ = angles
     fn.write("%0.6f %0.6f\n" % (rot, tilt))
 
 
-def geometryFromMatrix(matrix, inverseTransform=True):
-    from pwem.convert.transformations import (translation_from_matrix,
-                                              euler_from_matrix)
+def geometryFromMatrix(matrix):
+    from pwem.convert.transformations import euler_from_matrix
 
-    if inverseTransform:
-        matrix = inv(matrix)
-        shifts = -translation_from_matrix(matrix)
-    else:
-        shifts = translation_from_matrix(matrix)
+    matrix = inv(matrix)
     angles = -rad2deg(euler_from_matrix(matrix, axes='szyz'))
-    return shifts, angles
+
+    return angles
